#!/bin/sh
#----------------------------------------------------------------------------
# /etc/dhcpc/dhcpcd-hooks.sh - is called, if the ip-address hase changed
#
# Creation:	    04.05.2002  od
# Last Update:  $Id: dhcpcd-hooks.sh,v 1.2.2.2 2002/05/09 15:23:25 od Exp $
#----------------------------------------------------------------------------

#
# Prepare the USEPEERDNS functionality
#
create_resolv_conf() {
    i=1
    { for newdns in $DNS; do
          echo $i:nameserver $newdns
          i=`/usr/bin/expr $i + 1`
      done; } > /etc/ppp/resolv.conf
}

#
# Call User ip-up scripts
#
ip_up_scripts () {
    for i in /etc/ppp/ip-up.*
    do
        if [ -f $i ]
        then
            /usr/local/bin/dtou $i
            . $i
        fi
    done
}

#
# Call User ip-down scripts
#
ip_down_scripts () {
    for i in /etc/ppp/ip-down.*
    do
        if [ -f $i ]
        then
            /usr/local/bin/dtou $i
            . $i
        fi
    done
}

#
# Write the /etc/resolv.conf, if no ens is running an usepeerdns is 'yes'
#
write_resolv_conf () {
    if [ -f /var/run/$interface.usepeerdns ]            # $interface.usepeerdns existing?
    then
        usepeerdns=`cat /var/run/$interface.usepeerdns` # set usepeerdns yes or no
    else
        usepeerdns='no'                                 # set usepeerdns no
    fi

    if [ $usepeerdns = "no" ] || [ -f /usr/local/ens/ens.conf ]
    then
        cp /etc/dhcpc/resolv.conf.orig /etc/resolv.conf
    else
        set `grep "^search" /etc/dhcpc/resolv.conf.orig`
        local_search=$2
        set `grep "^search" /etc/resolv.conf`
        remote_search=$2
        echo "# Modified resolv.conf by /etc/dhcpc/dhcpcd-hooks.sh" > /tmp/resolv.conf
        sed "s/^search.*/search $local_search $remote_search/" /etc/resolv.conf >> /tmp/resolv.conf
        echo "" >> /tmp/resolv.conf
        mv /tmp/resolv.conf /etc/resolv.conf
    fi
}

#
# Call Hooks
#
exec_hooks () {

    if [ -f /etc/dhcpc/dhcpcd-$interface.cache ] && \
       [ -f /etc/dhcpc/dhcpcd-$interface.info ]
    then
        # interface ip hase changed
        . /etc/dhcpc/dhcpcd-$interface.info

        tty=''
        speed=''
        local=$IPADDR

        if [ "$GATEWAY" != "" ]
        then
            set $GATEWAY
            remote=$1
        else
            remote=''
        fi

        echo $IPADDR > /var/run/$interface.ip
        create_resolv_conf
        write_resolv_conf
        if [ -f /etc/dhcpc/dhcpcd-$interface.cache ]
        then
            # only call down-scripts, if interface was up before
            ip_down_scripts
        fi
        ip_up_scripts
    else
        # interface has no ip any more or info file is gone
        cp /etc/dhcpc/resolv.conf.orig /etc/resolv.conf
        ip_down_scripts
        rm -f /var/run/$interface.ip
    fi
}

#
# Here we go
#

# set -x

interface=`echo $0 | cut -d'-' -f2 | cut -d'.' -f1`
real_interface=$interface

if [ "$interface" = "" ]
then
    exit 0
fi

if [ -f /usr/bin/logger ]
then
    exec_hooks 2>&1 | logger -t dhcpcd
else
    exec_hooks 2>&1 > /dev/console
fi
